@@ -41,6 +41,20 @@ class BaseModel(models.Model):
     class Meta:
         abstract = True
 
+    def handle_create(self):
+        pass
+
+    def handle_update(self):
+        pass
+
+    def save(self, *args, **kwargs):
+        is_new = not self.pk
+        super(BaseModel, self).save(*args, **kwargs)
+        if is_new:
+            self.handle_create()
+        else:
+            self.handle_update()
+
 
 class BaseTrackedModel(BaseModel):
     class Meta:
@@ -55,7 +69,7 @@ class BaseTrackedModel(BaseModel):
 
     def __init__(self, *args, **kwargs):
         super(BaseTrackedModel, self).__init__(*args, **kwargs)
-        if self.editor and not self.creator: #TODO move this to save
+        if self.editor and not self.creator:  # TODO move this to save
             self.creator = self.editor
 
     @classmethod
